==> vagrant_1.4.3.orig.tar.gz: vagrant-1.4.3/test/unit/vagrant/plugin/v1/manager_test.rb <==
require File.expand_path("../../../../base", __FILE__)

describe Vagrant::Plugin::V1::Manager do
  include_context "unit"

  let(:instance) { described_class.new }

  def plugin
    p = Class.new(Vagrant.plugin("1"))
    yield p
    p
  end

  it "should enumerate registered communicator classes" do
    pA = plugin do |p|
      p.communicator("foo") { "bar" }
    end

    pB = plugin do |p|
      p.communicator("bar") { "baz" }
    end

    instance.register(pA)
    instance.register(pB)

    instance.communicators.length.should == 2
    instance.communicators[:foo].should == "bar"
    instance.communicators[:bar].should == "baz"
  end

  it "should enumerate registered configuration classes" do
    pA = plugin do |p|
      p.config("foo") { "bar" }
    end

    pB = plugin do |p|
      p.config("bar") { "baz" }
    end

    instance.register(pA)
    instance.register(pB)

    instance.config.length.should == 2
    instance.config[:foo].should == "bar"
    instance.config[:bar].should == "baz"
  end

  it "should enumerate registered upgrade safe config classes" do
    pA = plugin do |p|
      p.config("foo", true) { "bar" }
    end

    pB = plugin do |p|
      p.config("bar") { "baz" }
    end

    instance.register(pA)
    instance.register(pB)

    instance.config_upgrade_safe.length.should == 1
    instance.config_upgrade_safe[:foo].should == "bar"
  end

  it "should enumerate registered guest classes" do
    pA = plugin do |p|
      p.guest("foo") { "bar" }
    end

    pB = plugin do |p|
      p.guest("bar") { "baz" }
    end

    instance.register(pA)
    instance.register(pB)

    instance.guests.length.should == 2
    instance.guests[:foo].should == "bar"
    instance.guests[:bar].should == "baz"
  end

  it "should enumerate registered host classes" do
    pA = plugin do |p|
      p.host("foo") { "bar" }
    end

    pB = plugin do |p|
      p.host("bar") { "baz" }
    end

    instance.register(pA)
    instance.register(pB)

    instance.hosts.length.should == 2
    instance.hosts[:foo].should == "bar"
    instance.hosts[:bar].should == "baz"
  end

  it "should enumerate registered provider classes" do
    pA = plugin do |p|
      p.provider("foo") { "bar" }
    end

    pB = plugin do |p|
      p.provider("bar") { "baz" }
    end

    instance.register(pA)
    instance.register(pB)

    instance.providers.length.should == 2
    instance.providers[:foo].should == "bar"
    instance.providers[:bar].should == "baz"
  end
end

==> vagrant-2.4.1.tar.gz: vagrant-2.4.1/test/unit/vagrant/plugin/v1/manager_test.rb <==
# Copyright (c) HashiCorp, Inc.
# SPDX-License-Identifier: BUSL-1.1

require File.expand_path("../../../../base", __FILE__)

describe Vagrant::Plugin::V1::Manager do
  include_context "unit"

  let(:instance) { described_class.new }

  def plugin
    p = Class.new(Vagrant.plugin("1"))
    yield p
    p
  end

  it "should enumerate registered communicator classes" do
    pA = plugin do |p|
      p.communicator("foo") { "bar" }
    end

    pB = plugin do |p|
      p.communicator("bar") { "baz" }
    end

    instance.register(pA)
    instance.register(pB)

    expect(instance.communicators.length).to eq(2)
    expect(instance.communicators[:foo]).to eq("bar")
    expect(instance.communicators[:bar]).to eq("baz")
  end

  it "should enumerate registered configuration classes" do
    pA = plugin do |p|
      p.config("foo") { "bar" }
    end

    pB = plugin do |p|
      p.config("bar") { "baz" }
    end

    instance.register(pA)
    instance.register(pB)

    expect(instance.config.length).to eq(2)
    expect(instance.config[:foo]).to eq("bar")
    expect(instance.config[:bar]).to eq("baz")
  end

  it "should enumerate registered upgrade safe config classes" do
    pA = plugin do |p|
      p.config("foo", true) { "bar" }
    end

    pB = plugin do |p|
      p.config("bar") { "baz" }
    end

    instance.register(pA)
    instance.register(pB)

    expect(instance.config_upgrade_safe.length).to eq(1)
    expect(instance.config_upgrade_safe[:foo]).to eq("bar")
  end

  it "should enumerate registered guest classes" do
    pA = plugin do |p|
      p.guest("foo") { "bar" }
    end

    pB = plugin do |p|
      p.guest("bar") { "baz" }
    end

    instance.register(pA)
    instance.register(pB)

    expect(instance.guests.length).to eq(2)
    expect(instance.guests[:foo]).to eq("bar")
    expect(instance.guests[:bar]).to eq("baz")
  end

  it "should enumerate registered host classes" do
    pA = plugin do |p|
      p.host("foo") { "bar" }
    end

    pB = plugin do |p|
      p.host("bar") { "baz" }
    end

    instance.register(pA)
    instance.register(pB)

    expect(instance.hosts.length).to eq(2)
    expect(instance.hosts[:foo]).to eq("bar")
    expect(instance.hosts[:bar]).to eq("baz")
  end

  it "should enumerate registered provider classes" do
    pA = plugin do |p|
      p.provider("foo") { "bar" }
    end

    pB = plugin do |p|
      p.provider("bar") { "baz" }
    end

    instance.register(pA)
    instance.register(pB)

    expect(instance.providers.length).to eq(2)
    expect(instance.providers[:foo]).to eq("bar")
    expect(instance.providers[:bar]).to eq("baz")
  end
end
